//
// Glovedat.hpp:
//	Interface Definition of class GloveData.
//
// Purpose:
//	Provides access to the raw data read during a sample.
//
// Author(s): Mark Pflaging   C-serve  70233,1552
// Copyright 1992   Mark Thomas Pflaging
//
// Also see authorships in OOPGLOVE.DOC.
// Date:    5/15/92 - 9/21/92
//
#ifndef __GLOVEDAT_HPP
#define __GLOVEDAT_HPP

/***** GLOVE DATA SPECIFICATIONS **************

 The glove_data array has been simplified. These are its functions:


x =   X position, 3mm per number
y =   Y position, 3mm per number
z =   distance,  14mm per number
rot = wrist twist. 0 is up 1 is slightly CW, 5 is down, 11 is slightly CCW.
      About 30 to 40 degrees per count.

 Note: exact scaling of all above change with distance! Closer is higher res.

fingers = packed 2-bit values, 0 is open, 3 is (tight) fist:
	  Bit format: TtIiMmRr  for Thumb, Index, Middle, and Ring fingers.

keys: $FF is no key. Responds with 0 to 9 for keys "0" thru "9". $80 = Enter,
      $82 = START, $83 = SEL, $0A = "A", $0B = "B", 0 is "Center"
      Up,down,left,right are $0D,$0E,$0C,$0F respectively.
      (Enter added by MTP)
*/

// GloveData contains a union so that the call to
//	void gloveDriver::lowlevel_get_glove_data();
// can have "binary" access.
class GloveData {
	union {
		struct gloveData {
			signed char x;
			signed char y;
			signed char z;
			signed char rotation;
			signed char fingers;
			signed char keys;
		} tagGloveData;
		unsigned char data[1];  // size doesn't really matter!
	};

public:
	int getX()  { return( tagGloveData.x ); }
	void setX(int newx) { tagGloveData.x = newx; }
	int getY()  { return( tagGloveData.y ); }
	void setY(int newy) { tagGloveData.y = newy; }
	int getZ()  { return( tagGloveData.z ); }
	void setZ(int newz) { tagGloveData.z = newz; }
	int getRotation()  { return( tagGloveData.rotation ); }
	int getFingers()   { return( tagGloveData.fingers ); }
	int getKeys()      { return( tagGloveData.keys ); }

	enum dimensions { XChann = 0, YChann, ZChann, RotChann };
	int getChannel(dimensions which) { return (data[which]); }
	void setChannel(dimensions which, int newval) {
		data[which] = newval;
	}

protected:
	// getDataArea provided for the gloveDriver class.
	unsigned char *getDataArea() { return data; }
};
#endif
